@@ -362,7 +362,8 @@ typedef enum {
 	CAMEL_PROVIDER_CONF_LABEL,
 	CAMEL_PROVIDER_CONF_HIDDEN,
 	CAMEL_PROVIDER_CONF_OPTIONS,
-	CAMEL_PROVIDER_CONF_PLACEHOLDER
+	CAMEL_PROVIDER_CONF_PLACEHOLDER,
+	CAMEL_PROVIDER_CONF_ADVANCED_SECTION_START
 } CamelProviderConfType;
 
 /**
@@ -496,7 +497,9 @@ typedef enum { /*< flags >*/
 	CAMEL_STORE_CAN_EDIT_FOLDERS = 1 << 5,
 	CAMEL_STORE_USE_CACHE_DIR = 1 << 6,
 	CAMEL_STORE_CAN_DELETE_FOLDERS_AT_ONCE = 1 << 7,
-	CAMEL_STORE_SUPPORTS_INITIAL_SETUP = 1 << 8
+	CAMEL_STORE_SUPPORTS_INITIAL_SETUP = 1 << 8,
+	CAMEL_STORE_IS_BUILTIN = 1 << 9,
+	CAMEL_STORE_USE_TEMP_DIR = 1 << 10 /* for test purposes only */
 } CamelStoreFlags;
 
 /**
@@ -592,4 +595,124 @@ typedef enum {
 	CAMEL_TIME_UNIT_YEARS
 } CamelTimeUnit;
 
+/**
+ * CamelGpgTrust:
+ * @CAMEL_GPG_TRUST_NONE: no trust set
+ * @CAMEL_GPG_TRUST_UNKNOWN: unknown trust level
+ * @CAMEL_GPG_TRUST_NEVER: never trust the key
+ * @CAMEL_GPG_TRUST_MARGINAL: marginally trust the key
+ * @CAMEL_GPG_TRUST_FULL: fully trust the key
+ * @CAMEL_GPG_TRUST_ULTIMATE: ultimately trust the key
+ *
+ * GPG key trust levels.
+ *
+ * Since: 3.50
+ **/
+typedef enum {
+	CAMEL_GPG_TRUST_NONE		= 0,
+	CAMEL_GPG_TRUST_UNKNOWN		= 1,
+	CAMEL_GPG_TRUST_NEVER		= 2,
+	CAMEL_GPG_TRUST_MARGINAL	= 3,
+	CAMEL_GPG_TRUST_FULL		= 4,
+	CAMEL_GPG_TRUST_ULTIMATE	= 5
+} CamelGpgTrust;
+
+/**
+ * CamelStoreDBCountKind
+ * @CAMEL_STORE_DB_COUNT_KIND_TOTAL: all messages
+ * @CAMEL_STORE_DB_COUNT_KIND_UNREAD: only unread and not deleted messages
+ * @CAMEL_STORE_DB_COUNT_KIND_JUNK: only junk messages
+ * @CAMEL_STORE_DB_COUNT_KIND_DELETED: only deleted messages
+ * @CAMEL_STORE_DB_COUNT_KIND_NOT_JUNK_NOT_DELETED: all except of junk and deleted messages
+ * @CAMEL_STORE_DB_COUNT_KIND_NOT_JUNK_NOT_DELETED_UNREAD: all unread, except of junk and deleted messages
+ * @CAMEL_STORE_DB_COUNT_KIND_JUNK_NOT_DELETED: only junk messages, which are not deleted
+ *
+ * Represents a kind of the count the camel_store_db_count_messages()
+ * is asked to calculate.
+ *
+ * Since: 3.58
+ **/
+typedef enum _CamelStoreDBCountKind {
+	CAMEL_STORE_DB_COUNT_KIND_TOTAL = 1,
+	CAMEL_STORE_DB_COUNT_KIND_UNREAD,
+	CAMEL_STORE_DB_COUNT_KIND_JUNK,
+	CAMEL_STORE_DB_COUNT_KIND_DELETED,
+	CAMEL_STORE_DB_COUNT_KIND_NOT_JUNK_NOT_DELETED,
+	CAMEL_STORE_DB_COUNT_KIND_NOT_JUNK_NOT_DELETED_UNREAD,
+	CAMEL_STORE_DB_COUNT_KIND_JUNK_NOT_DELETED
+} CamelStoreDBCountKind;
+
+/**
+ * CamelDBSqlizeFlags:
+ * @CAMEL_DB_SQLIZE_FLAG_FULL: escape the text and enclose it into apostrophes
+ * @CAMEL_DB_SQLIZE_FLAG_ESCAPE_ONLY: only escape the text, without adding surrounding apostrophes
+ *
+ * Influences how the camel_db_sqlize_to_statement() behaves.
+ *
+ * Since: 3.58
+ **/
+typedef enum _CamelDBSqlizeFlags {
+	CAMEL_DB_SQLIZE_FLAG_FULL		= 0,
+	CAMEL_DB_SQLIZE_FLAG_ESCAPE_ONLY	= 1 << 0
+} CamelDBSqlizeFlags;
+
+/**
+ * CamelFolderThreadFlags:
+ * @CAMEL_FOLDER_THREAD_FLAG_NONE: no flag set
+ * @CAMEL_FOLDER_THREAD_FLAG_SUBJECT: thread by subject
+ * @CAMEL_FOLDER_THREAD_FLAG_SORT: sort threads by sent/received date
+ *
+ * Flags influencing what the resulting tree for camel_folder_thread_new()
+ * will look like.
+ *
+ * Since: 3.58
+ **/
+typedef enum _CamelFolderThreadFlags { /*< flags >*/
+	CAMEL_FOLDER_THREAD_FLAG_NONE		= 0,
+	CAMEL_FOLDER_THREAD_FLAG_SUBJECT	= 1 << 0,
+	CAMEL_FOLDER_THREAD_FLAG_SORT		= 1 << 1
+} CamelFolderThreadFlags;
+
+/**
+ * CamelMatchThreadsKind:
+ * @CAMEL_MATCH_THREADS_KIND_NONE: do not match on threads
+ * @CAMEL_MATCH_THREADS_KIND_ALL: include all related messages in the thread
+ * @CAMEL_MATCH_THREADS_KIND_REPLIES: include replies of the message
+ * @CAMEL_MATCH_THREADS_KIND_REPLIES_AND_PARENTS: include replies and parents
+ * @CAMEL_MATCH_THREADS_KIND_SINGLE: include messages not being in any thread
+ * @CAMEL_MATCH_THREADS_KIND_NOT_ALL: include messages not part of the %CAMEL_MATCH_THREADS_KIND_ALL (Since: 3.58.2)
+ *
+ * Kinds for "match-threads" search option.
+ *
+ * Since: 3.58
+ **/
+typedef enum _CamelMatchThreadsKind {
+	CAMEL_MATCH_THREADS_KIND_NONE = 0,
+	CAMEL_MATCH_THREADS_KIND_ALL,
+	CAMEL_MATCH_THREADS_KIND_REPLIES,
+	CAMEL_MATCH_THREADS_KIND_REPLIES_AND_PARENTS,
+	CAMEL_MATCH_THREADS_KIND_SINGLE,
+	CAMEL_MATCH_THREADS_KIND_NOT_ALL
+} CamelMatchThreadsKind;
+
+/**
+ * CamelVeeFolderOpFlags:
+ * @CAMEL_VEE_FOLDER_OP_FLAG_NONE: no flag set
+ * @CAMEL_VEE_FOLDER_OP_FLAG_SKIP_REBUILD: skip rebuild of the search folder
+ * @CAMEL_VEE_FOLDER_OP_FLAG_SKIP_EMIT: skip emit of internal "vee-setup-changed" signal
+ *
+ * Flags influencing behavior of some functions of a #CamelVeeFolder,
+ * like the camel_vee_folder_set_expression_sync(),
+ * camel_vee_folder_add_folder_sync (),
+ * camel_vee_folder_remove_folder_sync () and
+ * camel_vee_folder_set_folders_sync().
+ *
+ * Since: 3.58
+ **/
+typedef enum _CamelVeeFolderOpFlags { /*< flags >*/
+	CAMEL_VEE_FOLDER_OP_FLAG_NONE		= 0,
+	CAMEL_VEE_FOLDER_OP_FLAG_SKIP_REBUILD	= 1 << 0,
+	CAMEL_VEE_FOLDER_OP_FLAG_SKIP_EMIT	= 1 << 1
+} CamelVeeFolderOpFlags;
+
 #endif /* CAMEL_ENUMS_H */
