@@ -27,7 +27,6 @@
 
 #include <camel/camel-enums.h>
 #include <camel/camel-folder-summary.h>
-#include <camel/camel-object.h>
 
 /* Standard GObject macros */
 #define CAMEL_TYPE_FOLDER \
@@ -93,6 +92,21 @@ typedef enum {
 	CAMEL_FOLDER_ERROR_SUMMARY_INVALID
 } CamelFolderError;
 
+/**
+ * CamelFolderParamFlags:
+ * @CAMEL_FOLDER_PARAM_PERSISTENT:
+ *     The parameter is persistent, which means its value is saved to
+ *     the disk between sessions.
+ *
+ * These flags extend #GParamFlags.  Most of the time you will use them
+ * in conjunction with g_object_class_install_property().
+ *
+ * Since: 3.58
+ **/
+typedef enum {
+	CAMEL_FOLDER_PARAM_PERSISTENT = 1 << (G_PARAM_USER_SHIFT + 0)
+} CamelFolderParamFlags;
+
 /**
  * CamelFetchType:
  * @CAMEL_FETCH_OLD_MESSAGES: fetch old messages
@@ -135,12 +149,12 @@ struct _CamelFolderQuotaInfo {
 };
 
 struct _CamelFolder {
-	CamelObject parent;
+	GObject parent;
 	CamelFolderPrivate *priv;
 };
 
 struct _CamelFolderClass {
-	CamelObjectClass parent_class;
+	GObjectClass parent_class;
 
 	/* Non-Blocking Methods */
 	gint		(*get_message_count)	(CamelFolder *folder);
@@ -520,6 +534,15 @@ gboolean	camel_folder_search_body_sync	(CamelFolder *folder,
 						 GPtrArray **out_uids, /* gchar * */
 						 GCancellable *cancellable,
 						 GError **error);
+void		camel_folder_take_state_filename (CamelFolder *self,
+						  gchar *filename);
+const gchar *	camel_folder_get_state_filename (CamelFolder *self);
+void		camel_folder_save_state	(CamelFolder *self);
+void		camel_folder_load_state	(CamelFolder *self);
+void		camel_folder_class_map_legacy_property
+						(CamelFolderClass *folder_class,
+						 const gchar *prop_name,
+						 gint32 tag);
 
 /* update functions for change info */
 GType		camel_folder_change_info_get_type
